@@ -42,6 +42,9 @@ my $this_perl = $^X;
 $this_perl .= $Config{_exe} if $^O ne 'VMS' and $this_perl !~ m/$Config{_exe}$/i;
 
 
+# croaks on failure to execute
+# carps, not croak, if process has non-zero exit status
+# Devel::NYTProf::Data->new may croak, e.g., if data trucated
 sub profile_this {
     my %opt = @_;
 
@@ -52,6 +55,9 @@ sub profile_this {
             join(" ", @perl), $ENV{NYTPROF} || ''
         if 0;
 
+    # ensure child has same libs as us (e.g., if we were run with perl -Mblib)
+    local $ENV{PERL5LIB} = join($Config{path_sep}, @INC);
+
     if (my $src_file = $opt{src_file}) {
         system(@perl, $src_file) == 0
             or carp "@perl $src_file exited with an error status";
@@ -67,6 +73,11 @@ sub profile_this {
         croak "Neither src_file or src_code was provided";
     }
 
+    # undocumented hack that's handy for testing
+    if ($opt{htmlopen}) {
+        warn system("nytprofhtml --open --file='$out_file'");
+    }
+
     my $profile = Devel::NYTProf::Data->new( { filename => $out_file } );
 
     unlink $out_file;
